@@ -6,7 +6,7 @@ from nonebot.adapters.onebot.v11 import Message, MessageSegment
 from nonebot.params import Arg, CommandArg, ArgPlainText, RawCommand
 from .drawer import get_token, get_taskId, get_img
 
-drawer = on_command("画画", aliases={'油画', '水彩画', '卡通画', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
+drawer = on_command("画画", aliases={'油画', '水彩', '卡通', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
 
 
 @drawer.handle()
